package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Nov 17, 2025
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Clock interface {
Now() time.Time
}
Clock defines an interface for getting the current time.
type Config struct {
Clock Clock
}
Config contains configuration settings, including a Clock used to retrieve the current time.
Create initializes and returns a new instance of signr.Backend with default configuration values.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.